@@ -34,7 +34,9 @@ class Client(object):
             self.apiAddress = apiAddress
         else:
             self.apiAddress = Algorithmia.getApiAddress()
-        if caCert is None and 'REQUESTS_CA_BUNDLE' in os.environ:
+        if caCert == False:
+            self.requestSession.verify = False
+        elif caCert is None and 'REQUESTS_CA_BUNDLE' in os.environ:
             caCert = os.environ.get('REQUESTS_CA_BUNDLE')
             self.catCerts(caCert)
             self.requestSession.verify = self.ca_cert
